@@ -1,14 +1,14 @@
-# Copyrights 2007-2012 by [Mark Overmeer].
+# Copyrights 2007-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use warnings;
 use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '0.992';
+$VERSION = '0.993';
 
 use base 'Exporter';
 
@@ -347,7 +347,7 @@ sub __xn($$$@)   # repeated for prototype
 }
 
 
-sub N__($) {shift}
+sub N__($) { $_[0] }
 
 
 sub N__n($$) {@_}
